==> 0.0.1.tar.gz: lib/export_dev_package.dart <==
// ignore_for_file: avoid_print
library export_dev_package;

import 'dart:convert';
import 'dart:io';

Future move({
  required String packageName,
  required String importString,
  required String exportString,
  bool isDebug = false,
  List<String>? filterList,
  List<String> hideList = const [],
  String Function(String value)? replaceConvert,
}) async {
  String outPutFileName;
  String exportFileName;

  if (isDebug) {
    var s = "${DateTime.now().second}";
    outPutFileName = 'test/$packageName/lib/src/$packageName$s.dart';
    exportFileName = 'test/$packageName/lib/$packageName$s.dart';
  } else {
    outPutFileName = 'example/$packageName/lib/src/$packageName.dart';
    exportFileName = 'example/$packageName/lib/$packageName.dart';
  }

  var directory = Directory('lib');
  if (!directory.existsSync()) {
    print("directory.existsSync");
    Directory('lib').createSync();
  }
  var outPut = StringBuffer(importString);

  outPut.write(" " * 300);

  var filePathList = <String>[];
  var list = directory.listSync(recursive: true);

  for (var entity in list) {
    // print('${entity.path}');
    FileSystemEntity.type(entity.path).then((FileSystemEntityType type) {
      String label = "";
      // print('##$label：${entity.path}');
      //判断文件类型
      switch (type) {
        case FileSystemEntityType.directory:
          label = '目录';
          break;
        case FileSystemEntityType.file:
          label = '文件';
          // print('@@$label：${entity.path}');
          if (entity.path.contains("outPut")) {
            break;
          }
          filePathList.add(entity.path);
          File file = File(entity.path);
          if (!file.existsSync()) {
            print('${entity.path} 文件不存在了');
          } else {
            List<String> fileStr = file.readAsLinesSync(
                encoding: Platform.isMacOS ? latin1 : utf8);
            for (var element in fileStr) {
              var line = element.trim();
              var remove = line.isEmpty ||
                  line.startsWith("export") ||
                  line.startsWith("import") ||
                  line.startsWith("//") ||
                  line.startsWith("log") ||
                  line.startsWith("library") ||
                  line.startsWith("assert");
              var b = false;
              filterList?.forEach((element) {
                if (line.startsWith(element)) {
                  b = true;
                  return;
                }
              });
              //过滤
              if (!remove || b) {
                line = line.replaceAll('\n', '  ');
                line = line.replaceAll('@override', '@override ');
                line = line.replaceAll('@deprecated', '@deprecated ');
                //转换
                line = replaceConvert?.call(line) ?? line;
                outPut.write(line);
              }
            }
          }
          break;
        case FileSystemEntityType.link:
          label = '链接';
          break;
        default:
          label = '未知';
      }
    });
  }
  await Future.delayed(const Duration(seconds: 1), () async {
    var outPutFile = File(outPutFileName);
    if (!outPutFile.existsSync()) {
      outPutFile.createSync(recursive: true);
    }
    var out = outPut.toString();
    // out = outPut.toString().replaceAll('\n', '');
    outPutFile.writeAsStringSync(out, flush: true);
    outPut.clear();
    print("完成资源文件$outPutFileName");
  });

  await Future.delayed(const Duration(seconds: 1), () async {
    var yamlFile = File("example/pubspec.yaml");
    if (!yamlFile.existsSync()) {
      File("pubspec.yaml").copySync("example/pubspec.yaml");
      print("完成yaml文件example/pubspec.yaml");
    }
  });

  await Future.delayed(const Duration(seconds: 1), () async {
    var exportPutFile = File(exportFileName);

    if (!exportPutFile.existsSync()) {
      exportPutFile.createSync(recursive: true);
    }
    var exportPut = StringBuffer("library $packageName;\n");
    exportPut.writeln();
    exportPut.write(importString);
    exportPut.write("export 'package:$packageName/src/$packageName.dart'");
    for (var i = 0; i < hideList.length; i++) {
      var element = hideList[i];
      if (i == 0) {
        exportPut.write(" hide");
      } else if (i < hideList.length - 1) {
        exportPut.write(" $element,");
      } else {
        exportPut.write(" $element");
      }
    }
    exportPut.write(";\n");
    exportPut.write(exportString);

    ///
    var out = exportPut.toString();
    // out = outPut.toString().replaceAll('\n', '');
    exportPutFile.writeAsStringSync(out, flush: true);
    exportPut.clear();
    print("完成导出文件$exportFileName");
  });
  print("完成");
}

==> 0.0.2.tar.gz: lib/export_dev_package.dart <==
// ignore_for_file: avoid_print
library export_dev_package;

import 'dart:convert';
import 'dart:io';

Future move({
  required String packageName,
  required String importString,
  required String exportString,
  bool isDebug = false,
  List<String>? filterList,
  List<String> hideList = const [],
  String Function(String value)? replaceConvert,
}) async {
  String outPutFileName;
  String exportFileName;

  if (isDebug) {
    var s = "${DateTime.now().second}";
    outPutFileName = 'test/$packageName/lib/src/$packageName$s.dart';
    exportFileName = 'test/$packageName/lib/$packageName$s.dart';
  } else {
    outPutFileName = 'example/$packageName/lib/src/$packageName.dart';
    exportFileName = 'example/$packageName/lib/$packageName.dart';
  }

  var directory = Directory('lib');
  if (!directory.existsSync()) {
    print("directory.existsSync");
    Directory('lib').createSync();
  }
  var outPut = StringBuffer(importString);

  outPut.write(" " * 300);

  var filePathList = <String>[];
  var list = directory.listSync(recursive: true);

  for (var entity in list) {
    // print('${entity.path}');
    FileSystemEntity.type(entity.path).then((FileSystemEntityType type) {
      String label = "";
      // print('##$label：${entity.path}');
      //判断文件类型
      switch (type) {
        case FileSystemEntityType.directory:
          label = '目录';
          break;
        case FileSystemEntityType.file:
          label = '文件';
          // print('@@$label：${entity.path}');
          if (entity.path.contains("outPut")) {
            break;
          }
          filePathList.add(entity.path);
          File file = File(entity.path);
          if (!file.existsSync()) {
            print('${entity.path} 文件不存在了');
          } else {
            List<String> fileStr = file.readAsLinesSync(
                encoding: Platform.isMacOS ? latin1 : utf8);
            for (var element in fileStr) {
              var line = element.trim();
              var remove = line.isEmpty ||
                  line.startsWith("export") ||
                  line.startsWith("import") ||
                  line.startsWith("//") ||
                  line.startsWith("log") ||
                  line.startsWith("library") ||
                  line.startsWith("assert");
              var b = false;
              filterList?.forEach((element) {
                if (line.startsWith(element)) {
                  b = true;
                  return;
                }
              });
              //过滤
              if (!remove || b) {
                line = line.replaceAll('\n', '  ');
                line = line.replaceAll('@override', '@override ');
                line = line.replaceAll('@deprecated', '@deprecated ');
                //转换
                line = replaceConvert?.call(line) ?? line;
                outPut.write(line);
              }
            }
          }
          break;
        case FileSystemEntityType.link:
          label = '链接';
          break;
        default:
          label = '未知';
      }
    });
  }
  await Future.delayed(const Duration(seconds: 1), () async {
    var outPutFile = File(outPutFileName);
    if (!outPutFile.existsSync()) {
      outPutFile.createSync(recursive: true);
    }
    var out = outPut.toString();
    // out = outPut.toString().replaceAll('\n', '');
    outPutFile.writeAsStringSync(out, flush: true);
    outPut.clear();
    print("完成资源文件$outPutFileName");
  });

  await Future.delayed(const Duration(seconds: 1), () async {
    var yamlFile = File("example/pubspec.yaml");
    if (!yamlFile.existsSync()) {
      var file = File("pubspec.yaml");
      var yamlStr = StringBuffer();
      List<String> fileStr =
          file.readAsLinesSync(encoding: Platform.isMacOS ? latin1 : utf8);
      for (var element in fileStr) {
        var line = element;
        var remove =
            line.startsWith("  export_dev_package:") || line.startsWith("# ");
        if (!remove) {
          yamlStr.writeln(line);
        }
      }
      yamlFile.writeAsStringSync(yamlStr.toString(), flush: true);
      yamlStr.clear();
      print("完成yaml文件example/pubspec.yaml");
    }
  });

  await Future.delayed(const Duration(seconds: 1), () async {
    var exportPutFile = File(exportFileName);

    if (!exportPutFile.existsSync()) {
      exportPutFile.createSync(recursive: true);
    }
    var exportPut = StringBuffer("library $packageName;\n");
    exportPut.writeln();
    exportPut.write(importString);
    exportPut.write("export 'package:$packageName/src/$packageName.dart'");
    for (var i = 0; i < hideList.length; i++) {
      var element = hideList[i];
      if (i == 0) {
        exportPut.write(" hide");
      } else if (i < hideList.length - 1) {
        exportPut.write(" $element,");
      } else {
        exportPut.write(" $element");
      }
    }
    exportPut.write(";\n");
    exportPut.write(exportString);

    ///
    var out = exportPut.toString();
    // out = outPut.toString().replaceAll('\n', '');
    exportPutFile.writeAsStringSync(out, flush: true);
    exportPut.clear();
    print("完成导出文件$exportFileName");
  });
  print("完成");
}
